package com.fs.store.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsMenuMapper;
import com.fs.store.domain.FsMenu;
import com.fs.store.service.IFsMenuService;

/**
 * 用户端菜单管理Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsMenuServiceImpl implements IFsMenuService 
{
    @Autowired
    private FsMenuMapper fsMenuMapper;

    /**
     * 查询用户端菜单管理
     * 
     * @param menuId 用户端菜单管理ID
     * @return 用户端菜单管理
     */
    @Override
    public FsMenu selectFsMenuById(Long menuId)
    {
        return fsMenuMapper.selectFsMenuById(menuId);
    }

    /**
     * 查询用户端菜单管理列表
     * 
     * @param fsMenu 用户端菜单管理
     * @return 用户端菜单管理
     */
    @Override
    public List<FsMenu> selectFsMenuList(FsMenu fsMenu)
    {
        return fsMenuMapper.selectFsMenuList(fsMenu);
    }

    /**
     * 新增用户端菜单管理
     * 
     * @param fsMenu 用户端菜单管理
     * @return 结果
     */
    @Override
    public int insertFsMenu(FsMenu fsMenu)
    {
        fsMenu.setCreateTime(DateUtils.getNowDate());
        return fsMenuMapper.insertFsMenu(fsMenu);
    }

    /**
     * 修改用户端菜单管理
     * 
     * @param fsMenu 用户端菜单管理
     * @return 结果
     */
    @Override
    public int updateFsMenu(FsMenu fsMenu)
    {
        fsMenu.setUpdateTime(DateUtils.getNowDate());
        return fsMenuMapper.updateFsMenu(fsMenu);
    }

    /**
     * 批量删除用户端菜单管理
     * 
     * @param menuIds 需要删除的用户端菜单管理ID
     * @return 结果
     */
    @Override
    public int deleteFsMenuByIds(Long[] menuIds)
    {
        return fsMenuMapper.deleteFsMenuByIds(menuIds);
    }

    /**
     * 删除用户端菜单管理信息
     * 
     * @param menuId 用户端菜单管理ID
     * @return 结果
     */
    @Override
    public int deleteFsMenuById(Long menuId)
    {
        return fsMenuMapper.deleteFsMenuById(menuId);
    }
}
